.. include:: definitions.txt

.. _running:

Executing ProcGraph models
============================


There are two ways:


* **Using the command line**: A command line executable ``pg`` is included in ProcGraph.
  It is possible to run any model from the command line and pass any parameters.

  This is explained in :ref:`pg_program`.


* **Using the API**: Sometimes you want to embed |procgraph| in your models.
  There is a function ``pg()`` that allows you to call any model directly.  

  This is explained in :ref:`pg_function`.

..
	Advanced
	--------

	The function ``pg()`` and the command line executable ``pg`` do not offer
	any 

	In general, you are encouraged to create new blocks, instead of messing with model
	execution.

	This is explained in :ref:`pg_interactive`.


.. _pg_program:


The ``pg`` command line program
-------------------------------

|towrite|





.. _pg_function:


The ``pg()`` function
-------------------------------

|towrite|














